#!/bin/bash
#
# author           : Pedro Pinto (pnboy~AT~pinguix.com)
# latest update    : 22-06-2007
# source location  : http://www.aleksey.com/xmlsec/
# url              : http://www.aleksey.com/xmlsec/download/xmlsec1-$VERSION.tar.gz

NAME=xmlsec1
VERSION=1.2.10
ARCH=${ARCH:-i486}
CPU=${CPU:-i686}
BUILD=${BUILD:-48.1}
TMP=${TMP:-/tmp/$NAME}
PKG=$TMP/package-$NAME
CWD=`pwd`
EXTENSION=tar.gz
FILENAME=$NAME-$VERSION.$EXTENSION

#
# building-computer dependent: the number of parallel 'jobs' of 'make'
#
# 'heavy' computer: 6 build-jobs at once
#
numjobs='-j6'
#
# 'light' computer: 2 build-jobs at once
#
#numjobs='-j2'

rm -rf $PKG
mkdir -p $PKG

cd $TMP
rm -rf ${FILENAME/.$EXTENSION/}
  if [ -f $FILENAME ]; then
          echo "Source file already here, no need to re-download";
  elif [ -f $CWD/$FILENAME ]; then
          echo -n "Relocating source file to $TMP..."
          cp $CWD/$FILENAME $TMP/
	  echo "done"
  else
	  wget -c http://www.aleksey.com/xmlsec/download/$FILENAME
  fi
  tar xf $FILENAME

cd ${FILENAME/.$EXTENSION/}

# Configure:
export CFLAGS="-O2 -march=$ARCH -mtune=$CPU"
export CXXFLAGS="-O2 -march=$ARCH -mtune=$CPU"
./configure \
  --prefix=/usr \
  --with-nss=/usr/include/seamonkey-1.1.2/nss/ \
  --with-html-dir=/usr/doc/$NAME-$VERSION

# Build and install:
make $numjobs || exit 1
make install DESTDIR=$PKG || exit 1

# Strip binaries:
( cd $PKG
  find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
  find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
)

# Compress the man page(s)
if [ -d $PKG/usr/man ]; then
	find $PKG/usr/man -type f -name "*.?" -exec gzip -9f {} \;
fi
if [ -d $PKG/usr/info ]; then
	find $PKG/usr/info -type f -name "*.info*" -exec gzip -9f {} \;
fi

# Add a documentation directory:
mkdir -p $PKG/usr/doc/$NAME-$VERSION

# The Makefile evidently contains the package's license...
DOCS="AUTHORS README NEWS"
cd $TMP/$NAME-$VERSION
cp -a \
  $DOCS \
  $PKG/usr/doc/$NAME-$VERSION

# 
# as per package rules: add the build-file itself
#
mkdir -p $PKG/usr/src/$NAME-$VERSION
cp "$CWD/build-$NAME.sh" "$PKG/usr/src/$NAME-$VERSION/build-$NAME.sh"
chmod a+x "$PKG/usr/src/$NAME-$VERSION/build-$NAME.sh"

mkdir -p $PKG/install

#    |-----handy-ruler------------------------------------------------------|
echo "$NAME: $NAME (XML Security Library)
$NAME:
$NAME: XML Security Library is a companion C library to LibXML, supporting
$NAME: the major XML security standards: XML Signature, XML Encryption,
$NAME: Canonical XML, Exclusive Canonical XML.
$NAME: 
$NAME:
$NAME: 
$NAME: 
$NAME:
$NAME: " > $PKG/install/slack-desc

#
# real packaging work:
#
# Make sure ownerships and permissions are sane:
cd $PKG
chown -R root:root .
find . -perm 666 -exec chmod 644 {} \;
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;

makepkg -l y -c n ../$NAME-$VERSION-$ARCH-$BUILD.tgz

#
# computes the md5sum signature for the package
#
cd $TMP
md5sum $NAME-$VERSION-$ARCH-$BUILD.tgz > $NAME-$VERSION-$ARCH-$BUILD.md5
requiredbuilder -z $NAME-$VERSION-$ARCH-$BUILD.tgz > $NAME-$VERSION-$ARCH-$BUILD.dep

